       IDENTIFICATION DIVISION.
       PROGRAM-ID.     LHGREQ.
       AUTHOR.         LILA GODEL.
       DATE-COMPILED.
      ******************************************************
      *                                                    *
      *    This program reads the current century - 1 and  *
      *    a number of days from a file named lhgreq.cfg.  *
      *    Aftwards the system date is obtained and        *
      *    converted to its julian format.  The number     *
      *    of days read in is subtracted from this to      *
      *    create a new julian date.  This date is         *
      *    converted to a gregorian date and displayed to  *
      *    the user so they can determine if any offline   *
      *    file requests need to be deleted in wcFILE      *
      *    or the Wildcat message base.                    *
      *                                                    *
      ******************************************************
       ENVIRONMENT DIVISION.
       CONFIGURATION SECTION.
       SOURCE-COMPUTER.   IBM.
       OBJECT-COMPUTER.   IBM.
       INPUT-OUTPUT SECTION.
       FILE-CONTROL.
           SELECT CONFIGURATION-FILE
                  ASSIGN TO "lhgreq.cfg"
                  ORGANIZATION IS LINE SEQUENTIAL.
       DATA DIVISION.
       FILE SECTION.
       FD  CONFIGURATION-FILE.
       01  CONFIGURATION-RECORD.
           05  CR-CENTURY-1            PIC  9(02).
           05  CR-DAYSR.            
               10  CRD-1ST-DIGIT       PIC  9(01).
               10  CRD-2ND-DIGIT       PIC  9(01).
               10  CRD-3RD-DIGIT       PIC  9(01).
       WORKING-STORAGE SECTION.
       01  CALENDAR-VALUES.
           05  CV-JANUARY              PIC  9(05)      VALUE 01000.
           05  CV-FEBRUARY             PIC  9(05)      VALUE 02031.
           05  CV-MARCH                PIC  9(05)      VALUE 03059.
           05  CV-APRIL                PIC  9(05)      VALUE 04090.
           05  CV-MAY                  PIC  9(05)      VALUE 05120.
           05  CV-JUNE                 PIC  9(05)      VALUE 06151.
           05  CV-JULY                 PIC  9(05)      VALUE 07181.
           05  CV-AUGUST               PIC  9(05)      VALUE 08212.
           05  CV-SEPTEMBER            PIC  9(05)      VALUE 09243.
           05  CV-OCTOBER              PIC  9(05)      VALUE 10273.
           05  CV-NOVEMBER             PIC  9(05)      VALUE 11304.
           05  CV-DECEMBER             PIC  9(05)      VALUE 12334.
       01  CALENDAR REDEFINES CALENDAR-VALUES.
           05  C-MONTH-DAY             OCCURS 12 TIMES
                                       INDEXED BY DATES-INDEX.
               10  CMD-MONTH           PIC  9(02).
               10  CMD-DAYS            PIC  9(03).
       01  GREGORIAN-SYSTEM-DATE.
           05  GSD-YEAR                PIC  9(02).
           05  GSD-MONTH               PIC  9(02).
           05  GSD-DAY                 PIC  9(02).
       01  GREGORIAN-REQUEST-DATE.
           05  GRD-MONTH               PIC  9(02).
           05  GRD-DAY                 PIC  9(02).
           05  GRD-YEAR                PIC  9(02).
       01  JULIAN-SYSTEM-DATE.
           05  JSD-DAYS                PIC  9(03).
           05  JSD-YEAR                PIC  9(02).
       01  JULIAN-REQUEST-DATE.
           05  JRD-DAYS                PIC  9(03).
           05  JRD-YEAR                PIC  9(02).
       01  FIELDS-FOR-CALCULATIONS.
           05  FFC-YEAR.
               10  FFCY-1ST-DIGITS     PIC  9(02).
               10  FFCY-2ND-DIGITS     PIC  9(02).
           05  FFC-YEAR2               PIC  9(04).
           05  FFC-DAYSR               PIC  9(03).
       01  ANSWERS                                     VALUE ZEROS.
           05  DIVISION-QUOTIENT       PIC  9(02)V99.
           05  DIVISION-REMAINDER      PIC  9(02).
       01  FLAGS.
           05  DIVISIBLE               PIC  X(03)      VALUE "NO".
           05  DIVISIBLE2              PIC  X(03)      VALUE "NO".
       01  REQUEST-DATA.
           05  RD-MESSAGE1             PIC  X(33)      VALUE
               "All requests posted on or before ".
           05  RD-DATE                 PIC  99/99/99.
           05  RD-MESSAGE2             PIC  X(38)      VALUE
               " have been made available for at least".
           05  RD-DAYS.
               10  RDD-1ST-DIGIT       PIC  X(01)      VALUE SPACES.
               10  RDD-2ND-DIGIT       PIC  X(01)      VALUE SPACES.
               10  RDD-3RD-DIGIT       PIC  X(01)      VALUE SPACES.
           05  RD-MESSAGE3             PIC  X(39)      VALUE
               " days and can now be deleted in wcFILE ".
           05  RD-MESSAGE4             PIC  X(33)      VALUE 
               "and the Wildcat message database.".
       01  FINISH.
           05  F-PROMPT                PIC  X(26)      VALUE
               "PRESS ANY KEY TO CONTINUE.".
           05  F-NOTHING               PIC  X(01)      VALUE SPACES.
       SCREEN SECTION.
       01  REQUEST-DATA-SCREEN.
           05  LINE 01 COLUMN 01       PIC  X(33)      FROM RD-MESSAGE1.
           05  LINE 01 COLUMN 34       PIC  99/99/99   FROM RD-DATE.
           05  LINE 01 COLUMN 42       PIC  X(38)      FROM RD-MESSAGE2.
           05  LINE 02 COLUMN 01       PIC  ZZ9        FROM RD-DAYS.
           05  LINE 02 COLUMN 04       PIC  X(39)      FROM RD-MESSAGE3.
       01  FINISH-SCREEN.
           05  LINE 04 COLUMN 01       PIC  X(26)      FROM F-PROMPT.
           05  LINE 04 COLUMN 27       PIC  X(01)      TO F-NOTHING 
                                                       AUTO.
       PROCEDURE DIVISION.
       1000-CONTROL SECTION.
      ******************************************************
      *                                                    *
      *    This section is the main controlling section    *
      *    for the program.  It invokes the paragraphs     *
      *    in the other sections in the logical order      *
      *    nesscary for the program to carry out its       *
      *    function.                                       *
      *                                                    *
      ******************************************************
       1100-CONTROL.
      ******************************************************
      *                                                    *
      *    This paragraph is the main controlling          *
      *    paragraph in this section.                      *
      *                                                    *
      ******************************************************
           PERFORM 5000-FILES.
           PERFORM 3100-GET-SYSTEM-DATE.
           PERFORM 3200-LEAP-YEAR-TEST.
           PERFORM 2100-GREGORIAN-TO-JULIAN.
           PERFORM 3300-COMPUTE-REQUEST-DATE.
           PERFORM 2200-JULIAN-TO-GREGORIAN.
           PERFORM 4000-REQUEST-DATA.
           STOP RUN.
       2000-DATE-CONVERSIONS SECTION.
      ******************************************************
      *                                                    *
      *    This section contains a paragraph for           *
      *    converting the system date from its gregorian   *
      *    form to its julian form and a paragraph for     *
      *    converting the request date from its julian     *
      *    form to its gregorian form.                     *
      *                                                    *
      ******************************************************
       2100-GREGORIAN-TO-JULIAN.
      ******************************************************
      *                                                    *
      *    This paragraph converts the system date from    *
      *    its gregorian form to its julian form.          *
      *                                                    *
      ******************************************************
           SET DATES-INDEX TO 1.
           SEARCH C-MONTH-DAY
                 AT END DISPLAY "SEARCHED FAILED."
                   WHEN GSD-MONTH = CMD-MONTH (DATES-INDEX)
                        ADD CMD-DAYS (DATES-INDEX) TO GSD-DAY
                        GIVING JSD-DAYS
                        MOVE GSD-YEAR TO JSD-YEAR.
       2200-JULIAN-TO-GREGORIAN.
      ******************************************************
      *                                                    *
      *    This paragraph converts the request date from   *
      *    its julian form to its gregorian form.          *
      *                                                    *
      ******************************************************
           MOVE JRD-YEAR TO GRD-YEAR.
           SET DATES-INDEX TO 1.
           SEARCH C-MONTH-DAY
                 AT END
                   IF  JRD-DAYS > CMD-DAYS (12)
                       MOVE 12 TO GRD-MONTH
                       SUBTRACT JRD-DAYS FROM CMD-DAYS (12)
                       GIVING GRD-DAY
                   END-IF
                   WHEN JRD-DAYS >= CMD-DAYS (DATES-INDEX) AND
                        JRD-DAYS <= CMD-DAYS (DATES-INDEX + 1)
                        MOVE CMD-MONTH (DATES-INDEX) TO GRD-MONTH
                        SUBTRACT JRD-DAYS FROM CMD-DAYS (DATES-INDEX)
                        GIVING GRD-DAY.
       3000-CALCULATION SECTION.
      ******************************************************
      *                                                    *
      *    This section contains paragraphs for all of     *
      *    the calculations the program needs to perform.  *
      *                                                    *
      ******************************************************
       3100-GET-SYSTEM-DATE.
      ******************************************************
      *                                                    *
      *    This paragraph obtains the current system       *
      *    date and initializes some of the fields for     *
      *    calculations.                                   *
      *                                                    *
      ******************************************************
           ACCEPT GREGORIAN-SYSTEM-DATE FROM DATE.
           MOVE GSD-YEAR TO FFCY-2ND-DIGITS.
           MOVE FFC-YEAR TO FFC-YEAR2.
       3200-LEAP-YEAR-TEST.
      ******************************************************
      *                                                    *
      *    This paragraph determines if a date whose year  *
      *    is in FFC-YEAR has a leap year.  If it does     *
      *    the values for CV-MARCH thru CV-DECEMBER are    *
      *    adjusted to include values one higher than      *
      *    their original values.  If it does not the      *
      *    values for CV-MARCH thru CV-DECEMBER are        *
      *    adjusted to include values one higher than      *
      *    their original values.  A leap year is any year *
      *    which equally divisible by 4 and if equally     *
      *    divisible by 100 is alos equally divisible by   *
      *    400.                                            *
      *                                                    *
      ******************************************************
           DIVIDE FFC-YEAR2 BY 4  GIVING DIVISION-QUOTIENT
           REMAINDER DIVISION-REMAINDER.
           IF  DIVISION-REMAINDER = 0
               MOVE "YES" TO DIVISIBLE
               DIVIDE FFC-YEAR2 BY 100 GIVING DIVISION-QUOTIENT
               REMAINDER DIVISION-REMAINDER
               IF  DIVISION-REMAINDER = 0
                   DIVIDE FFC-YEAR2 BY 400 GIVING DIVISION-QUOTIENT
                   REMAINDER DIVISION-REMAINDER
                   IF  DIVISION-REMAINDER = 0
                       MOVE "YES" TO DIVISIBLE2
                   ELSE
                       MOVE "NO" TO DIVISIBLE2
               ELSE
                   MOVE "YES" TO DIVISIBLE2
           ELSE
               MOVE "NO" TO DIVISIBLE.
           IF  DIVISIBLE = "YES" AND DIVISIBLE2 = "YES"
               MOVE 03060 TO CV-MARCH
               MOVE 04091 TO CV-APRIL
               MOVE 05121 TO CV-MAY
               MOVE 06152 TO CV-JUNE
               MOVE 07182 TO CV-JULY
               MOVE 08213 TO CV-AUGUST
               MOVE 09244 TO CV-SEPTEMBER
               MOVE 10274 TO CV-OCTOBER
               MOVE 11305 TO CV-NOVEMBER
               MOVE 12335 TO CV-DECEMBER
           ELSE
               MOVE 03059 TO CV-MARCH
               MOVE 04090 TO CV-APRIL
               MOVE 05120 TO CV-MAY
               MOVE 06151 TO CV-JUNE
               MOVE 07181 TO CV-JULY
               MOVE 08212 TO CV-AUGUST
               MOVE 09243 TO CV-SEPTEMBER
               MOVE 10273 TO CV-OCTOBER
               MOVE 11304 TO CV-NOVEMBER
               MOVE 12334 TO CV-DECEMBER.
       3300-COMPUTE-REQUEST-DATE.
      *******************************************************
      *                                                    *
      *    This paragraph subtracts the number of days     *
      *    read in from the julian form of the current     *
      *    system date to obtain the julian request date.  *                          *
      *                                                    *
      ******************************************************
           IF  GSD-MONTH = 01 AND GSD-DAY <= FFC-DAYSR
               SUBTRACT 1 FROM FFC-YEAR2 GIVING JRD-YEAR
           ELSE
               MOVE JSD-YEAR TO JRD-YEAR.
           MOVE JRD-YEAR TO FFCY-2ND-DIGITS.
           MOVE FFC-YEAR TO FFC-YEAR2.
           IF  GSD-YEAR = 00 AND JRD-YEAR = 99
               SUBTRACT 1 FROM FFCY-1ST-DIGITS GIVING FFCY-1ST-DIGITS.
           PERFORM 3200-LEAP-YEAR-TEST.
           IF  JSD-DAYS > FFC-DAYSR
               COMPUTE JRD-DAYS = (JSD-DAYS) - (FFC-DAYSR)
           ELSE
               COMPUTE JRD-DAYS = (CV-DECEMBER + 31) - (FFC-DAYSR)
                                  + (JSD-DAYS).
       4000-REQUEST-DATA SECTION.
      ******************************************************
      *                                                    *
      *    This section contains a paragraph for           *
      *    displaying the gregorian form of the request    *
      *    date to the user followed by a pause prompt     *
      *    so the data does not scroll off of their        *
      *    screen before they can read it.                 *
      *                                                    *
      ******************************************************
       4100-DISPLAY-DATA.
      ******************************************************
      *                                                    *
      *    This paragraph displays the gregorian form      *
      *    gregorian form of the request date to the user  *
      *    followed by a pause prompt so the data does     *
      *    not scroll off of their screen before they      *
      *    can read it.                                    *
      *                                                    *
      ******************************************************
           MOVE GREGORIAN-REQUEST-DATE TO RD-DATE.
           DISPLAY REQUEST-DATA-SCREEN.
           DISPLAY FINISH-SCREEN.
           ACCEPT FINISH-SCREEN.
       5000-FILES SECTION.
      ******************************************************
      *                                                    *
      *    This section contains paragraphs for opening,   *
      *    reading, and closing the configuration file.    *
      *                                                    *
      ******************************************************
       5100-OPEN-CONFIGURATION-FILE.
      ******************************************************
      *                                                    *
      *    This paragraph opens the configuration file.    *
      *                                                    *
      ******************************************************
           OPEN INPUT CONFIGURATION-FILE.
       5200-READ-CONFIGURATION-FILE.
      ******************************************************
      *                                                    *
      *    This paragraph reads the configuration file.    *
      *                                                    *
      ******************************************************
           READ CONFIGURATION-FILE.
           MOVE CR-CENTURY-1 TO FFCY-1ST-DIGITS.
           MOVE CR-DAYSR TO FFC-DAYSR.
           IF  CRD-2ND-DIGIT = 0 AND CRD-1ST-DIGIT = 0
               MOVE CRD-3RD-DIGIT TO RDD-1ST-DIGIT
               MOVE " " TO RDD-2ND-DIGIT
               MOVE "d" TO RDD-3RD-DIGIT
               MOVE "ays and can now be deleted in wcFILE." 
               TO RD-MESSAGE3
           ELSE
               IF  CRD-1ST-DIGIT = 0
                   MOVE CRD-3RD-DIGIT TO RDD-2ND-DIGIT
                   MOVE CRD-2ND-DIGIT TO RDD-1ST-DIGIT
                   MOVE " " TO RDD-3RD-DIGIT
                   MOVE "days and can now be deleted in wcFILE." 
                   TO RD-MESSAGE3
               ELSE
                   MOVE CRD-3RD-DIGIT TO RDD-3RD-DIGIT
                   MOVE CRD-2ND-DIGIT TO RDD-2ND-DIGIT
                   MOVE CRD-1ST-DIGIT TO RDD-1ST-DIGIT.
               IF  CRD-2ND-DIGIT = 0 AND CRD-1ST-DIGIT = 0 AND
                   CRD-3RD-DIGIT = 1
                   MOVE CRD-3RD-DIGIT TO RDD-1ST-DIGIT
                   MOVE " " TO RDD-2ND-DIGIT
                   MOVE "d" TO RDD-3RD-DIGIT
                   MOVE "ay and can now be deleted in wcFILE"
                   TO RD-MESSAGE3.
       5300-CLOSE-CONFIGURATION-FILE.
      ******************************************************
      *                                                    *
      *    This paragraph closes the configuration file.   *
      *                                                    *
      ******************************************************
           CLOSE CONFIGURATION-FILE.
